[][src]Struct samp::cell::string::AmxString

pub struct AmxString<'amx> { /* fields omitted */ }

Methods

impl<'amx> AmxString<'amx>[src]

pub unsafe fn new(buffer: Buffer<'amx>, bytes: &[u8]) -> AmxString<'amx>[src]

Create a new AmxString from an allocated buffer and fill it with a string

pub fn to_bytes(&self) -> Vec<u8>[src]

Convert an AMX string to a Vec<u8>.

pub fn to_string(&self) -> String[src]

Convert an AMX string to a String. Only ASCII chars by default. Pass cp1251 to crate features to enable Windows 1251 encoding (TODO).

Example

use samp_sdk::cell::AmxString;


fn log_error(&self, amx: &Amx, text: AmxString) -> AmxResult<bool> {
    if !self.logger_enabled {
        return Ok(false);
    }

    let string = text.to_string();
    println!("[{}] PluginName error: {}", current_date(), string);

    Ok(true)
}

pub fn len(&self) -> usize[src]

Return a length of a string.

pub fn is_empty(&self) -> bool[src]

pub fn bytes_len(&self) -> usize[src]

Return a length of a buffer of a string